@@ -49,7 +49,7 @@ data['joomla'] = {}
 data['hubzero'] = {}
 config = ConfigParser.RawConfigParser()
 config.read('/etc/hubzero.conf')
-section = config.get('default','site')
+section = config.get('DEFAULT','site')
 docroot = config.get(section, 'DocumentRoot')
 
 file_read = open(docroot + '/configuration.php',"r")
